/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.common.ui.javafx.lwfxef.visual.widgets;

import javafx.geometry.Bounds;
import javafx.geometry.Pos;
import javafx.geometry.VPos;
import javafx.scene.text.Text;
import javafx.scene.text.TextAlignment;

/**
 * Text shape that automatically sets its translation to achieve text alignment.
 * 
 */
public class AlignedText extends Text {

	/**
	 * The alignment to be achieved by setting the translation.
	 */
	private Pos alignment = Pos.BOTTOM_LEFT;

	/**
	 * 
	 */
	public AlignedText() {
		super();
		this.setTextAlignment(TextAlignment.LEFT);
		this.setTextOrigin(VPos.TOP);
		this.boundsInLocalProperty().addListener(o -> updatePosition());
		this.baselineOffsetProperty().addListener(o -> updatePosition());
	}

	/** Returns alignment. */
	public Pos getAlignment() {
		return alignment;
	}

	/** Sets alignment. */
	public void setAlignment(Pos alignment) {
		this.alignment = alignment;
		updatePosition();
	}

	/** Sets the translation. */
	private void updatePosition() {
		Bounds bounds = getBoundsInLocal();

		double translateX = 0;
		switch(alignment.getHpos()) {
			case LEFT:
				translateX = 0;
				break;
			case CENTER:
				translateX = -bounds.getWidth() / 2;
				break;
			case RIGHT:
				translateX = -bounds.getWidth();
				break;
		}
		setTranslateX(translateX);

		setTextOrigin(alignment.getVpos());
	}
}
